@@ -17,6 +17,7 @@
 #include <QStandardPaths>
 
 // KF includes
+#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KMessageBox>
@@ -501,10 +502,15 @@ void Mainwindow::menuClearStatistics()
     message = i18n("Do you really want to clear the all time "
                     "statistical data?");
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(this,
+#else
     if (KMessageBox::Yes == KMessageBox::questionYesNo(this,
+#endif
                                                        message,
                                                        QString(),
-                                                       KStandardGuiItem::clear()))
+                                                       KStandardGuiItem::clear(),
+                                                       KStandardGuiItem::cancel()))
     {
         QHashIterator<int,Player *> it = mLSkatConfig->playerIterator();
         while (it.hasNext())
